<?php

class tiendaBD {

    private $server = "localhost";
    private $user = "root";
    private $pass = "";
    private $bd = "tienda";
    private $conn;
    public $error;

    function __construct() {
        $this->conectar();
    }

    function __destruct() {
        $this->conn = null;
    }

    /**
     * Esta función nos conecta a la base de de datos
     * @return PDOCon Conexión a la base de datos
     */
    private function conectar() {
        try {
            $this->conn = new PDO("mysql:host=$this->server;dbname=$this->bd", $this->user, $this->pass);
            $this->conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            return true;
        } catch (Exception $e) {

            $this->error = "Connection failed: " . $e->getMessage() . $e->getLine() . $e->getCode();
            return false;
        }
    }

    /**
     * Obtiene las filas de un sql
     * @param string $sql Consulta select
     * @return array $rows filas
     */
    function getSqlRows($sql) {
        try {

            $resul = $this->conn->query($sql);
            $rows = $resul->fetchAll(PDO::FETCH_ASSOC);
            return $rows;
        } catch (Exception $ex) {
            $this->error = "Error consulta: " . $ex->getMessage() . " - " . $sql;
            return null;
        }
    }

    /**
     * Devuelve las filas de una tabla
     * @param string $table Tabla de la que queremos los registros
     * @param number $limit Número máximo de elementos
     */
    function getTableRows($table, $limit = 20) {
        $sql = "select * from $table limit $limit";
        return $this->getSqlRows($sql);
    }

    function preparaSQL($tabla, $campos) {
        $c = array_keys($campos);
        $sql = "insert into $tabla (" . implode(",", $c) . ") values (:" . implode(",:", $c) . ")";
        return $sql;
    }

    private function insertar($tabla, $campos) {
        try {
            $sql = $this->preparaSQL($tabla, $campos);
            $st = $this->conn->prepare($sql);
            $st->execute($campos);
            return $this->conn->lastInsertId();
        } catch (Exception $ex) {
            $this->error = "Error consulta: " . $ex->getMessage() . " - " . $sql;

            return null;
        }
    }

    private function borrar($tabla, $clave) {
        try {
            $sql = "delete from $tabla where " . key($clave) . "=:" . key($clave);

            $st = $this->conn->prepare($sql);
            $st->execute($clave);
            return true;
        } catch (Exception $ex) {
            $this->error = "Error consulta: " . $ex->getMessage() . " - " . $sql;

            return false;
        }
    }

    private function update($tabla, $campos, $clave) {
        $sql = "update $tabla set ";
        foreach ($campos as $c => $v) {
            if ($c != $clave) {
                $sql .= $c . "=:" . $c.", ";
            }
        }
        $sql= substr($sql, 0,-2);
        $sql .= " where $clave=:$clave";
        try {

            $st = $this->conn->prepare($sql);
            $st->execute($campos);

            return true;
        } catch (Exception $ex) {
            $this->error = "Error consulta: " . $ex->getMessage() . " - " . $sql;

            return false;
        }
    }

    private function getById($tabla, $clave) {
        try {
            $sql = "select * from $tabla where " . key($clave) . "=:" . key($clave);

            $st = $this->conn->prepare($sql);
            $st->execute($clave);
            $res = $st->fetch(PDO::FETCH_ASSOC);
            return $res;
        } catch (Exception $ex) {
            $this->error = "Error consulta: " . $ex->getMessage() . " - " . $sql;

            return false;
        }
    }

    function insertarCliente($mail, $password, $direccion, $cpostal, $ciudad) {
        return $this->insertar('clientes', array('mail' => $mail, 'password' => $password, 'direccion' => $direccion, 'cpostal' => $cpostal, 'ciudad' => $ciudad));
    }

    function borrarCliente($id) {
        return $this->borrar('clientes', array('idclientes' => $id));
    }

    function getCliente($id) {
        return $this->getById('clientes', array('idclientes' => $id));
    }

    function updateCliente($campos) {
        if (empty($campos['password'])) {
            unset($campos['password']);
        }
        else{
            $campos['password']=md5($campos['password']);
        }
        return $this->update('clientes', $campos, 'idclientes');
    }

    function tableInfo($tabla) {
        return $this->getSqlRows("show columns from $tabla");
    }

}
