<?php

class BD {

    private $server = "localhost";
    private $user = "root";
    private $pass = "";
    private $bd;
    private $conn;
    private $error;

    function __construct($bd) {
        $this->bd = $bd;
        $this->conectar();
    }

    function __destruct() {
        $this->conn = null;
    }

    /**
     * Esta función nos conecta a la base de de datos
     * @return PDOCon Conexión a la base de datos
     */
    private function conectar() {
        try {
            $this->conn = new PDO("mysql:host=$this->server;dbname=$this->bd", $this->user, $this->pass);
            $this->conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            return true;
        } catch (Exception $e) {

            $this->error = "Connection failed: " . $e->getMessage() . $e->getLine() . $e->getCode();
            return false;
        }
    }

    /**
     * Obtiene las filas de un sql
     * @param string $sql Consulta select
     * @return array $rows filas
     */
    function getSqlRows($sql) {
        try {

            $resul = $this->conn->query($sql);
            $rows = $resul->fetchAll(PDO::FETCH_ASSOC);
            return $rows;
        } catch (Exception $ex) {
            $this->error = "Error consulta: " . $ex->getMessage() . " - " . $sql;
            return null;
        }
    }

    /**
     * Devuelve las filas de una tabla
     * @param string $table Tabla de la que queremos los registros
     * @param number $limit Número máximo de elementos
     */
    function getTableRows($table, $limit = 20) {
        $sql = "select * from $table limit $limit";
        return $this->getSqlRows($sql);
    }

    function preparaSQL($tabla, $campos) {
        $c = array_keys($campos);
        $sql = "insert into $tabla (" . implode(",", $c) . ") values (:" . implode(",:", $c) . ")";
        return $sql;
    }

    protected function insertar($tabla, $campos) {
        try {

            $st = $this->conn->prepare($this->preparaSQL($tabla, $campos));
            $st->execute($campos);
            return $this->conn->lastInsertId();
        } catch (Exception $ex) {

            return null;
        }
    }

}

class tiendaDB extends BD {

    
    
   
    function insertarCliente($mail, $password, $direccion, $cpostal, $ciudad) {
        return $this->insertar('clientes', array('mail' => $mail, 'password' => $password, 'direccion' => $direccion, 'cpostal' => $cpostal, 'ciudad' => $ciudad));
    }
   
}

$mitienda=new tiendaDB();

